Class ContainerAnalysisClient
- All Implemented Interfaces:
BackgroundResource,AutoCloseable
Analysis results are stored as a series of occurrences. An `Occurrence` contains information about a specific analysis instance on a resource. An occurrence refers to a `Note`. A note contains details describing the analysis and is generally stored in a separate project, called a `Provider`. Multiple occurrences can refer to the same note.
For example, an SSL vulnerability could affect multiple images. In this case, there would be one note for the vulnerability and an occurrence for each image with the vulnerability referring to that note.
This class provides the ability to make remote calls to the backing service through method calls that map to API methods. Sample code to get started:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) {
ResourceName resource =
new ResourceName() {
{@literal @}Override
public Map<String, String> getFieldValuesMap() {
Map<String, String> fieldValuesMap = new HashMap<>();
fieldValuesMap.put("resource", "projects/project-8432/notes/note-8432");
return fieldValuesMap;
}
{@literal @}Override
public String getFieldValue(String fieldName) {
return getFieldValuesMap().get(fieldName);
}
{@literal @}Override
public String toString() {
return "projects/project-8432/notes/note-8432";
}
};
Policy policy = Policy.newBuilder().build();
Policy response = containerAnalysisClient.setIamPolicy(resource, policy);
}
Note: close() needs to be called on the ContainerAnalysisClient object to clean up resources such as threads. In the example above, try-with-resources is used, which automatically calls close().
| Method | Description | Method Variants |
|---|---|---|
SetIamPolicy |
Sets the access control policy on the specified note or occurrence. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or an occurrence, respectively. The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
GetIamPolicy |
Gets the access control policy for a note or an occurrence resource. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or occurrence, respectively. The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
TestIamPermissions |
Returns the permissions that a caller has on the specified note or occurrence. Requires list permission on the project (for example, `containeranalysis.notes.list`). The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
GetVulnerabilityOccurrencesSummary |
Gets a summary of the number and severity of occurrences. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
ExportSBOM |
Generates an SBOM for the given resource. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
See the individual methods for example code.
Many parameters require resource names to be formatted in a particular way. To assist with these names, this class includes a format method for each type of name, and additionally a parse method to extract the individual identifiers contained within names that are returned.
This class can be customized by passing in a custom instance of ContainerAnalysisSettings to create(). For example:
To customize credentials:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
ContainerAnalysisSettings containerAnalysisSettings =
ContainerAnalysisSettings.newBuilder()
.setCredentialsProvider(FixedCredentialsProvider.create(myCredentials))
.build();
ContainerAnalysisClient containerAnalysisClient =
ContainerAnalysisClient.create(containerAnalysisSettings);
To customize the endpoint:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
ContainerAnalysisSettings containerAnalysisSettings =
ContainerAnalysisSettings.newBuilder().setEndpoint(myEndpoint).build();
ContainerAnalysisClient containerAnalysisClient =
ContainerAnalysisClient.create(containerAnalysisSettings);
To use REST (HTTP1.1/JSON) transport (instead of gRPC) for sending and receiving requests over the wire:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
ContainerAnalysisSettings containerAnalysisSettings =
ContainerAnalysisSettings.newHttpJsonBuilder().build();
ContainerAnalysisClient containerAnalysisClient =
ContainerAnalysisClient.create(containerAnalysisSettings);
Please refer to the GitHub repository's samples for more quickstart code snippets.
-
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedConstructs an instance of ContainerAnalysisClient, using the given settings.protected -
Method Summary
Modifier and TypeMethodDescriptionbooleanawaitTermination(long duration, TimeUnit unit) final voidclose()static final ContainerAnalysisClientcreate()Constructs an instance of ContainerAnalysisClient with default settings.static final ContainerAnalysisClientcreate(ContainerAnalysisSettings settings) Constructs an instance of ContainerAnalysisClient, using the given settings.static final ContainerAnalysisClientcreate(ContainerAnalysisStub stub) Constructs an instance of ContainerAnalysisClient, using the given stub for making calls.final ExportSBOMResponseexportSBOM(ExportSBOMRequest request) Generates an SBOM for the given resource.Generates an SBOM for the given resource.Returns a new GrafeasClient with the same configured settings.final PolicygetIamPolicy(ResourceName resource) Gets the access control policy for a note or an occurrence resource.final PolicygetIamPolicy(GetIamPolicyRequest request) Gets the access control policy for a note or an occurrence resource.final PolicygetIamPolicy(String resource) Gets the access control policy for a note or an occurrence resource.Gets the access control policy for a note or an occurrence resource.getStub()Gets a summary of the number and severity of occurrences.getVulnerabilityOccurrencesSummary(ProjectName parent, String filter) Gets a summary of the number and severity of occurrences.getVulnerabilityOccurrencesSummary(String parent, String filter) Gets a summary of the number and severity of occurrences.Gets a summary of the number and severity of occurrences.booleanbooleanfinal PolicysetIamPolicy(ResourceName resource, Policy policy) Sets the access control policy on the specified note or occurrence.final PolicysetIamPolicy(SetIamPolicyRequest request) Sets the access control policy on the specified note or occurrence.final PolicysetIamPolicy(String resource, Policy policy) Sets the access control policy on the specified note or occurrence.Sets the access control policy on the specified note or occurrence.voidshutdown()voidtestIamPermissions(ResourceName resource, List<String> permissions) Returns the permissions that a caller has on the specified note or occurrence.Returns the permissions that a caller has on the specified note or occurrence.testIamPermissions(String resource, List<String> permissions) Returns the permissions that a caller has on the specified note or occurrence.Returns the permissions that a caller has on the specified note or occurrence.
-
Constructor Details
-
ContainerAnalysisClient
Constructs an instance of ContainerAnalysisClient, using the given settings. This is protected so that it is easy to make a subclass, but otherwise, the static factory methods should be preferred.- Throws:
IOException
-
ContainerAnalysisClient
-
-
Method Details
-
getGrafeasClient
Returns a new GrafeasClient with the same configured settings.- Throws:
IOException
-
create
Constructs an instance of ContainerAnalysisClient with default settings.- Throws:
IOException
-
create
public static final ContainerAnalysisClient create(ContainerAnalysisSettings settings) throws IOException Constructs an instance of ContainerAnalysisClient, using the given settings. The channels are created based on the settings passed in, or defaults for any settings that are not set.- Throws:
IOException
-
create
Constructs an instance of ContainerAnalysisClient, using the given stub for making calls. This is for advanced usage - prefer using create(ContainerAnalysisSettings). -
getSettings
-
getStub
-
setIamPolicy
Sets the access control policy on the specified note or occurrence. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or an occurrence, respectively.The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { ResourceName resource = new ResourceName() { {@literal @}Override public Map<String, String> getFieldValuesMap() { Map<String, String> fieldValuesMap = new HashMap<>(); fieldValuesMap.put("resource", "projects/project-8432/notes/note-8432"); return fieldValuesMap; } {@literal @}Override public String getFieldValue(String fieldName) { return getFieldValuesMap().get(fieldName); } {@literal @}Override public String toString() { return "projects/project-8432/notes/note-8432"; } }; Policy policy = Policy.newBuilder().build(); Policy response = containerAnalysisClient.setIamPolicy(resource, policy); }- Parameters:
resource- REQUIRED: The resource for which the policy is being specified. See the operation documentation for the appropriate value for this field.policy- REQUIRED: The complete policy to be applied to the `resource`. The size of the policy is limited to a few 10s of KB. An empty policy is a valid policy but certain Cloud Platform services (such as Projects) might reject them.- Throws:
ApiException- if the remote call fails
-
setIamPolicy
Sets the access control policy on the specified note or occurrence. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or an occurrence, respectively.The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { String resource = ProjectName.of("[PROJECT]").toString(); Policy policy = Policy.newBuilder().build(); Policy response = containerAnalysisClient.setIamPolicy(resource, policy); }- Parameters:
resource- REQUIRED: The resource for which the policy is being specified. See the operation documentation for the appropriate value for this field.policy- REQUIRED: The complete policy to be applied to the `resource`. The size of the policy is limited to a few 10s of KB. An empty policy is a valid policy but certain Cloud Platform services (such as Projects) might reject them.- Throws:
ApiException- if the remote call fails
-
setIamPolicy
Sets the access control policy on the specified note or occurrence. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or an occurrence, respectively.The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { SetIamPolicyRequest request = SetIamPolicyRequest.newBuilder() .setResource("SetIamPolicyRequest1223629066".toString()) .setPolicy(Policy.newBuilder().build()) .setUpdateMask(FieldMask.newBuilder().build()) .build(); Policy response = containerAnalysisClient.setIamPolicy(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
setIamPolicyCallable
Sets the access control policy on the specified note or occurrence. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or an occurrence, respectively.The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { SetIamPolicyRequest request = SetIamPolicyRequest.newBuilder() .setResource("SetIamPolicyRequest1223629066".toString()) .setPolicy(Policy.newBuilder().build()) .setUpdateMask(FieldMask.newBuilder().build()) .build(); ApiFuture<Policy> future = containerAnalysisClient.setIamPolicyCallable().futureCall(request); // Do something. Policy response = future.get(); } -
getIamPolicy
Gets the access control policy for a note or an occurrence resource. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or occurrence, respectively.The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { ResourceName resource = new ResourceName() { {@literal @}Override public Map<String, String> getFieldValuesMap() { Map<String, String> fieldValuesMap = new HashMap<>(); fieldValuesMap.put("resource", "projects/project-8432/notes/note-8432"); return fieldValuesMap; } {@literal @}Override public String getFieldValue(String fieldName) { return getFieldValuesMap().get(fieldName); } {@literal @}Override public String toString() { return "projects/project-8432/notes/note-8432"; } }; Policy response = containerAnalysisClient.getIamPolicy(resource); }- Parameters:
resource- REQUIRED: The resource for which the policy is being requested. See the operation documentation for the appropriate value for this field.- Throws:
ApiException- if the remote call fails
-
getIamPolicy
Gets the access control policy for a note or an occurrence resource. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or occurrence, respectively.The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { String resource = ProjectName.of("[PROJECT]").toString(); Policy response = containerAnalysisClient.getIamPolicy(resource); }- Parameters:
resource- REQUIRED: The resource for which the policy is being requested. See the operation documentation for the appropriate value for this field.- Throws:
ApiException- if the remote call fails
-
getIamPolicy
Gets the access control policy for a note or an occurrence resource. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or occurrence, respectively.The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { GetIamPolicyRequest request = GetIamPolicyRequest.newBuilder() .setResource("GetIamPolicyRequest-1527610370".toString()) .setOptions(GetPolicyOptions.newBuilder().build()) .build(); Policy response = containerAnalysisClient.getIamPolicy(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
getIamPolicyCallable
Gets the access control policy for a note or an occurrence resource. Requires `containeranalysis.notes.setIamPolicy` or `containeranalysis.occurrences.setIamPolicy` permission if the resource is a note or occurrence, respectively.The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { GetIamPolicyRequest request = GetIamPolicyRequest.newBuilder() .setResource("GetIamPolicyRequest-1527610370".toString()) .setOptions(GetPolicyOptions.newBuilder().build()) .build(); ApiFuture<Policy> future = containerAnalysisClient.getIamPolicyCallable().futureCall(request); // Do something. Policy response = future.get(); } -
testIamPermissions
public final TestIamPermissionsResponse testIamPermissions(ResourceName resource, List<String> permissions) Returns the permissions that a caller has on the specified note or occurrence. Requires list permission on the project (for example, `containeranalysis.notes.list`).The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { ResourceName resource = new ResourceName() { {@literal @}Override public Map<String, String> getFieldValuesMap() { Map<String, String> fieldValuesMap = new HashMap<>(); fieldValuesMap.put("resource", "projects/project-8432/notes/note-8432"); return fieldValuesMap; } {@literal @}Override public String getFieldValue(String fieldName) { return getFieldValuesMap().get(fieldName); } {@literal @}Override public String toString() { return "projects/project-8432/notes/note-8432"; } }; List<String> permissions = new ArrayList<>(); TestIamPermissionsResponse response = containerAnalysisClient.testIamPermissions(resource, permissions); }- Parameters:
resource- REQUIRED: The resource for which the policy detail is being requested. See the operation documentation for the appropriate value for this field.permissions- The set of permissions to check for the `resource`. Permissions with wildcards (such as '*' or 'storage.*') are not allowed. For more information see [IAM Overview](https://cloud.google.com/iam/docs/overview#permissions).- Throws:
ApiException- if the remote call fails
-
testIamPermissions
public final TestIamPermissionsResponse testIamPermissions(String resource, List<String> permissions) Returns the permissions that a caller has on the specified note or occurrence. Requires list permission on the project (for example, `containeranalysis.notes.list`).The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { String resource = ProjectName.of("[PROJECT]").toString(); List<String> permissions = new ArrayList<>(); TestIamPermissionsResponse response = containerAnalysisClient.testIamPermissions(resource, permissions); }- Parameters:
resource- REQUIRED: The resource for which the policy detail is being requested. See the operation documentation for the appropriate value for this field.permissions- The set of permissions to check for the `resource`. Permissions with wildcards (such as '*' or 'storage.*') are not allowed. For more information see [IAM Overview](https://cloud.google.com/iam/docs/overview#permissions).- Throws:
ApiException- if the remote call fails
-
testIamPermissions
Returns the permissions that a caller has on the specified note or occurrence. Requires list permission on the project (for example, `containeranalysis.notes.list`).The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { TestIamPermissionsRequest request = TestIamPermissionsRequest.newBuilder() .setResource("TestIamPermissionsRequest942398222".toString()) .addAllPermissions(new ArrayList<String>()) .build(); TestIamPermissionsResponse response = containerAnalysisClient.testIamPermissions(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
testIamPermissionsCallable
public final UnaryCallable<TestIamPermissionsRequest,TestIamPermissionsResponse> testIamPermissionsCallable()Returns the permissions that a caller has on the specified note or occurrence. Requires list permission on the project (for example, `containeranalysis.notes.list`).The resource takes the format `projects/[PROJECT_ID]/notes/[NOTE_ID]` for notes and `projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]` for occurrences.
Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { TestIamPermissionsRequest request = TestIamPermissionsRequest.newBuilder() .setResource("TestIamPermissionsRequest942398222".toString()) .addAllPermissions(new ArrayList<String>()) .build(); ApiFuture<TestIamPermissionsResponse> future = containerAnalysisClient.testIamPermissionsCallable().futureCall(request); // Do something. TestIamPermissionsResponse response = future.get(); } -
getVulnerabilityOccurrencesSummary
public final VulnerabilityOccurrencesSummary getVulnerabilityOccurrencesSummary(ProjectName parent, String filter) Gets a summary of the number and severity of occurrences.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { ProjectName parent = ProjectName.of("[PROJECT]"); String filter = "filter-1274492040"; VulnerabilityOccurrencesSummary response = containerAnalysisClient.getVulnerabilityOccurrencesSummary(parent, filter); }- Parameters:
parent- Required. The name of the project to get a vulnerability summary for in the form of `projects/[PROJECT_ID]`.filter- The filter expression.- Throws:
ApiException- if the remote call fails
-
getVulnerabilityOccurrencesSummary
public final VulnerabilityOccurrencesSummary getVulnerabilityOccurrencesSummary(String parent, String filter) Gets a summary of the number and severity of occurrences.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { String parent = ProjectName.of("[PROJECT]").toString(); String filter = "filter-1274492040"; VulnerabilityOccurrencesSummary response = containerAnalysisClient.getVulnerabilityOccurrencesSummary(parent, filter); }- Parameters:
parent- Required. The name of the project to get a vulnerability summary for in the form of `projects/[PROJECT_ID]`.filter- The filter expression.- Throws:
ApiException- if the remote call fails
-
getVulnerabilityOccurrencesSummary
public final VulnerabilityOccurrencesSummary getVulnerabilityOccurrencesSummary(GetVulnerabilityOccurrencesSummaryRequest request) Gets a summary of the number and severity of occurrences.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { GetVulnerabilityOccurrencesSummaryRequest request = GetVulnerabilityOccurrencesSummaryRequest.newBuilder() .setParent(ProjectName.of("[PROJECT]").toString()) .setFilter("filter-1274492040") .build(); VulnerabilityOccurrencesSummary response = containerAnalysisClient.getVulnerabilityOccurrencesSummary(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
getVulnerabilityOccurrencesSummaryCallable
public final UnaryCallable<GetVulnerabilityOccurrencesSummaryRequest,VulnerabilityOccurrencesSummary> getVulnerabilityOccurrencesSummaryCallable()Gets a summary of the number and severity of occurrences.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { GetVulnerabilityOccurrencesSummaryRequest request = GetVulnerabilityOccurrencesSummaryRequest.newBuilder() .setParent(ProjectName.of("[PROJECT]").toString()) .setFilter("filter-1274492040") .build(); ApiFuture<VulnerabilityOccurrencesSummary> future = containerAnalysisClient.getVulnerabilityOccurrencesSummaryCallable().futureCall(request); // Do something. VulnerabilityOccurrencesSummary response = future.get(); } -
exportSBOM
Generates an SBOM for the given resource.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { ExportSBOMRequest request = ExportSBOMRequest.newBuilder().setName("name3373707").build(); ExportSBOMResponse response = containerAnalysisClient.exportSBOM(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
exportSBOMCallable
Generates an SBOM for the given resource.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (ContainerAnalysisClient containerAnalysisClient = ContainerAnalysisClient.create()) { ExportSBOMRequest request = ExportSBOMRequest.newBuilder().setName("name3373707").build(); ApiFuture<ExportSBOMResponse> future = containerAnalysisClient.exportSBOMCallable().futureCall(request); // Do something. ExportSBOMResponse response = future.get(); } -
close
public final void close()- Specified by:
closein interfaceAutoCloseable
-
shutdown
public void shutdown()- Specified by:
shutdownin interfaceBackgroundResource
-
isShutdown
public boolean isShutdown()- Specified by:
isShutdownin interfaceBackgroundResource
-
isTerminated
public boolean isTerminated()- Specified by:
isTerminatedin interfaceBackgroundResource
-
shutdownNow
public void shutdownNow()- Specified by:
shutdownNowin interfaceBackgroundResource
-
awaitTermination
- Specified by:
awaitTerminationin interfaceBackgroundResource- Throws:
InterruptedException
-