Class ContainerAnalysisSettings
java.lang.Object
com.google.api.gax.rpc.ClientSettings<ContainerAnalysisSettings>
com.google.cloud.devtools.containeranalysis.v1.ContainerAnalysisSettings
@Generated("by gapic-generator-java")
public class ContainerAnalysisSettings
extends ClientSettings<ContainerAnalysisSettings>
Settings class to configure an instance of
ContainerAnalysisClient.
The default instance has everything set to sensible defaults:
- The default service address (containeranalysis.googleapis.com) and default port (443) are used.
- Credentials are acquired automatically through Application Default Credentials.
- Retries are configured for idempotent methods but not for non-idempotent methods.
The builder of this class is recursive, so contained classes are themselves builders. When build() is called, the tree of builders is called to create the complete settings object.
For example, to set the [RetrySettings](https://cloud.google.com/java/docs/reference/gax/latest/com.google.api.gax.retrying.RetrySettings) of setIamPolicy:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
ContainerAnalysisSettings.Builder containerAnalysisSettingsBuilder =
ContainerAnalysisSettings.newBuilder();
containerAnalysisSettingsBuilder
.setIamPolicySettings()
.setRetrySettings(
containerAnalysisSettingsBuilder
.setIamPolicySettings()
.getRetrySettings()
.toBuilder()
.setInitialRetryDelayDuration(Duration.ofSeconds(1))
.setInitialRpcTimeoutDuration(Duration.ofSeconds(5))
.setMaxAttempts(5)
.setMaxRetryDelayDuration(Duration.ofSeconds(30))
.setMaxRpcTimeoutDuration(Duration.ofSeconds(60))
.setRetryDelayMultiplier(1.3)
.setRpcTimeoutMultiplier(1.5)
.setTotalTimeoutDuration(Duration.ofSeconds(300))
.build());
ContainerAnalysisSettings containerAnalysisSettings = containerAnalysisSettingsBuilder.build();
Please refer to the [Client Side Retry
Guide](https://docs.cloud.google.com/java/docs/client-retries) for additional support in setting
retries.-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classBuilder for ContainerAnalysisSettings. -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedContainerAnalysisSettings(ContainerAnalysisSettings.Builder settingsBuilder) -
Method Summary
Modifier and TypeMethodDescriptionstatic final ContainerAnalysisSettingsReturns a builder for the default credentials for this service.Returns a builder for the default ExecutorProvider for this service.Returns a builder for the default gRPC ChannelProvider for this service.Returns a builder for the default REST ChannelProvider for this service.static TransportChannelProviderReturns the object with the settings used for calls to exportSBOM.static StringReturns the default service endpoint.Returns the default service scopes.Returns the object with the settings used for calls to getIamPolicy.Returns the object with the settings used for calls to getVulnerabilityOccurrencesSummary.Returns a new gRPC builder for this class.newBuilder(ClientContext clientContext) Returns a new builder for this class.Returns a new REST builder for this class.Returns the object with the settings used for calls to setIamPolicy.Returns the object with the settings used for calls to testIamPermissions.Returns a builder containing all the values of this settings class.Methods inherited from class com.google.api.gax.rpc.ClientSettings
getApiKey, getBackgroundExecutorProvider, getClock, getCredentialsProvider, getEndpoint, getExecutorProvider, getGdchApiAudience, getHeaderProvider, getInternalHeaderProvider, getQuotaProjectId, getStubSettings, getTransportChannelProvider, getUniverseDomain, getWatchdogCheckInterval, getWatchdogCheckIntervalDuration, getWatchdogProvider, toString
-
Constructor Details
-
ContainerAnalysisSettings
protected ContainerAnalysisSettings(ContainerAnalysisSettings.Builder settingsBuilder) throws IOException - Throws:
IOException
-
-
Method Details
-
setIamPolicySettings
Returns the object with the settings used for calls to setIamPolicy. -
getIamPolicySettings
Returns the object with the settings used for calls to getIamPolicy. -
testIamPermissionsSettings
public UnaryCallSettings<TestIamPermissionsRequest,TestIamPermissionsResponse> testIamPermissionsSettings()Returns the object with the settings used for calls to testIamPermissions. -
getVulnerabilityOccurrencesSummarySettings
public UnaryCallSettings<GetVulnerabilityOccurrencesSummaryRequest,VulnerabilityOccurrencesSummary> getVulnerabilityOccurrencesSummarySettings()Returns the object with the settings used for calls to getVulnerabilityOccurrencesSummary. -
exportSBOMSettings
Returns the object with the settings used for calls to exportSBOM. -
create
public static final ContainerAnalysisSettings create(ContainerAnalysisStubSettings stub) throws IOException - Throws:
IOException
-
defaultExecutorProviderBuilder
Returns a builder for the default ExecutorProvider for this service. -
getDefaultEndpoint
Returns the default service endpoint. -
getDefaultServiceScopes
Returns the default service scopes. -
defaultCredentialsProviderBuilder
Returns a builder for the default credentials for this service. -
defaultGrpcTransportProviderBuilder
Returns a builder for the default gRPC ChannelProvider for this service. -
defaultHttpJsonTransportProviderBuilder
@BetaApi public static InstantiatingHttpJsonChannelProvider.Builder defaultHttpJsonTransportProviderBuilder()Returns a builder for the default REST ChannelProvider for this service. -
defaultTransportChannelProvider
-
defaultApiClientHeaderProviderBuilder
-
newBuilder
Returns a new gRPC builder for this class. -
newHttpJsonBuilder
Returns a new REST builder for this class. -
newBuilder
Returns a new builder for this class. -
toBuilder
Returns a builder containing all the values of this settings class.- Specified by:
toBuilderin classClientSettings<ContainerAnalysisSettings>
-